@@ -182,21 +182,20 @@ class hexagon_grid:
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
         if self.area_threshold == None:
-            area_threshold = (spacing*spacing)*0.33
-            disolve_hexa = dissolve_polygon(final_hexa, area_threshold).geosolution
-            hexagon = gpd.overlay(gdf, disolve_hexa, how = 'union')
+            area_thres = (spacing*spacing)*0.33
+            hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
             check_topology(df)
             self.geosolution = df
-        elif 0.0 >= self.area_threshold >= 0.8 and self.area_threshold != None:
-            raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
-        else:
+        elif 0.0 < self.area_threshold <= 0.8:
             area_thres = (spacing*spacing)*self.area_threshold
-            disolve_hexa = dissolve_polygon(final_hexa, area_thres).geosolution
-            hexagon = gpd.overlay(gdf, disolve_hexa, how = 'union')
+            hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
             df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
             check_topology(df)
             self.geosolution = df
+        else:
+            raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
+
 
 class merge_shapefile:
     
